@@ -35,10 +35,7 @@ EOF
 		mkdir -p /etc/Wireless/RT2870STA
 		cp RT2870STA.dat /etc/Wireless/RT2870STA/
 	fi	
-
-	if [ ! -f /lib/modules/$deb_addver-$deb_appendver/kernel/drivers/net/wireless/rt5370sta.ko ]; then
-		cp rt5370sta.ko /lib/modules/$deb_addver-$deb_appendver/kernel/drivers/net/wireless/
-	fi
+	cp rt5370sta.ko /lib/modules/$deb_addver-$deb_appendver/kernel/drivers/net/wireless/
 }
 
 install_linux_image()
@@ -53,7 +50,6 @@ install_linux_image()
 	if [ -f $flash_kernel ]; then
 		cp -v $flash_kernel /usr/sbin/flash-kernel
 	fi
-	cp -v rc.local /etc/
 	echo "Installing linux image and linux headers debian package"
 	dpkg -i *${model}*.deb
 	
